==> benno-web-2.8.0.tgz: srv/benno/bennoweb/htdocs/ctrl/a_cachereq.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Asynchronous request from frontend
 *
 * The frontend will get the ovarall numer of mails from here and put it into
 * the according span element at the frontend.
 *
 */

$searchstring = uniqid('dummy_');
$search_limit = 1;

$queryId = sha1($searchstring);
$SimpleQuery = new Query($queryId,$archive,$searchstring);

try {
    $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
    $App->setSession('mailCount',$QueryResult->overall);
    // clear flag
    $App->unsetSession('ENABLE_CACHE_WARMING_REQUEST');
    $App->response($QueryResult->numAll(),'text/plain');
}
catch (Exception $e) {
    $App->log('[a_cachereq] '.$e->getMessage(),3);
}

// no more output needed!
exit;
?>

==> benno-web-2.10.8.tgz: srv/benno/bennoweb/htdocs/ctrl/a_cachereq.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * Asynchronous request from frontend
 *
 * The frontend will get the ovarall numer of mails from here and put it into
 * the according span element at the frontend.
 *
 */

$searchstring = uniqid('dummy_');
$search_limit = 1;

$queryId = sha1($searchstring);
$SimpleQuery = new Query($queryId,$searchstring);

try {
    $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
    $App->setSession('mailCount',$QueryResult->overall);
    // clear flag
    $App->unsetSession('ENABLE_CACHE_WARMING_REQUEST');
    $App->response($QueryResult->numAll(),'text/plain');
}
catch (Exception $e) {
    $App->log('[a_cachereq] '.$e->getMessage(),3);
}

// no more output needed!
exit;
?>
